# Calculation of the flow rate of a rock-ramp pass

The calculation of the flow rate of a rock-ramp pass corresponds to the implementation of the algorithm and the equations present in
*Cassan L, Laurens P. 2016. Design of emergent and submerged rock-ramp fish passes. Knowl. Manag. Aquat. Ecosyst. 417, 45, <https://doi.org/10.1051/kmae/2016032>*.

## General calculation principle

There are three possibilities:

- the submerged case when \(h \ge 1.1 \times k\)
- the emergent case when \(h \le k\)
- the quasi-emergent case when \(k < h < 1.1 \times k\)

In the quasi-emergent case, the calculation of the flow corresponds to a transition between emergent and submerged case formulas:

$$Q = a \times Q_{submerge} + (1 - a) \times Q_{emergent}$$

with \(a = \dfrac{h / k - 1}{1.1 - 1}\)

## Submerged case

The calculation is done by integrating the velocity profile in and above the macro-roughnesses.
The calculated velocities are the temporal and spatial averages per plane parallel to the bottom.

In macro-roughnesses, velocities are obtained by double averaging the Navier-Stokes equations in uniform regime with a mixing length model for turbulence.

Above the macro-roughnesses, the classical turbulent boundary layer analysis is maintained.
The velocity profile is continuous at the top of the macro-roughnesses and is dependent on the boundary conditions set by the hydraulics:

- velocity at the bottom (without turbulence) in m/s:

$$u_0 = \sqrt{2 g S D (1 - \sigma C)/(C_d C)}$$

- total shear stress at the top of the roughnesses in m/s:

$$u_* = \sqrt{gS(h-k)}$$

The average bed velocity is given by integrating the flows between and above the blocks:

$$\bar{u} = \frac{Q_{inf} + Q_{sup}}{h}$$

with respectively \(Q_{inf}\) and \(Q_{sup}\) the unit flows for the part in the canopy and the part above the canopy.

### Calculation of the unit flow rate *Q<sub>inf</sub>* in the canopy

The flow in the canopy is obtained by integrating the velocity profile (Eq. 9, Cassan et al., 2016):

$$Q_{inf} = \int_{0}^1 u(\tilde{z}) d \tilde{z}$$

with

$$u(\tilde{z}) = u_0 \sqrt{\beta \left( \frac{h}{k} -1 \right) \frac{\sinh(\beta \tilde{z})}{\cosh(\beta)} + 1}$$

with

$$\beta = \sqrt{(k / \alpha_t)(C_d C k / D)/(1 - \sigma C)}$$

with \(\sigma = 1\) for \(C_{d0} = 2\) (square blocks), \(\sigma = \pi/4\) otherwise (circular blocks)

and \(\alpha_t\) obtained by solving the following equation:

$$\alpha_t u(1) - l_0 u_* = 0$$

with

$$l_0 = \min \left( s, 0.15 k \right)$$

with

$$s = D \left( \frac{1}{\sqrt{C}} - 1 \right)$$

### Calculation of the unit flow *Q<sub>sup</sub>* above the canopy

$$Q_{sup} = \int_k^h u(z) dz$$

with (Eq. 12, Cassan et al., 2016)

$$u(z) = \frac{u_*}{\kappa} \ln \left( \frac{z - d}{z_0} \right)$$

with (Eq. 14, Cassan et al., 2016)

$$z_0 = (k - d) \exp \left( {\frac{-\kappa u_k}{u_*}} \right)$$

and (Eq. 13, Cassan et al., 2016)

$$ d =  k - \frac{\alpha_t u_k}{\kappa u_*}$$

which gives

$$Q_{sup} = \frac{u_*}{\kappa} \left( (h - d) \left( \ln \left( \frac{h-d}{z_0} \right) - 1\right)  - \left( (k - d) \left( \ln \left( \frac{k-d}{z_0} \right) - 1 \right) \right) \right)$$

## Emerging case

The calculation of the flow rate is done by successive iterations which consist in finding the flow rate value allowing to obtain the equality between the flow velocity \(V\) and the average velocity of the bed given by the equilibrium of the friction forces (bottom + drag) with gravity:

$$u_0 = \sqrt{\frac{2 g S D (1 - \sigma C)}{C_d C (1 + N)}}$$

with

$$C_d = C_{d0} (1 + 0.4 / h_*^2) f_F(F)$$

$$N = \frac{\alpha C_f}{C_d C h_*}$$

with

$$\alpha = 1 - (a_y / a_x \times C)$$

## Formulas used

### Throughput speed *V*

$$V = \frac{Q}{B \times h}$$

### Average speed between blocks *V<sub>g</sub>*

$$V_g = \frac{V}{1 - \sqrt{(a_x/a_y)C}}$$

### Froude *F*

$$F = \frac{V_g}{\sqrt{gh}}$$

### Froude-related drag coefficient correction function *f<sub>F</sub>(F)*

If \(F < 1.3\) (Eq. 5, Cassan et al., 2016)

$$f_F(F) = \mathrm{min} \left( \frac{0.4 C_{d0} + 0.7}{1- (F^2 / 4)}, \frac{1}{F^{\frac{2}{3}}} \right)^2$$

else

$$f_F(F) = F^{\frac{-4}{3}}$$

(The distinction is only numerical because \(1- (F^2 / 4)\) is not defined for \(F > 2\))

### Coefficient of friction of the bed *C<inf>f</inf>*

If \(k_s < 10^{-6} \mathrm{m}\) then we use Blasius' formula

$$C_f = 0.3164 / 4 * Re^{-0.25}$$

with

$$Re = u_0 \times h / \nu$$

Else (Eq. 3, Cassan et al., 2016 d'après Rice et al., 1998)

$$C_f = \frac{2}{(5.1 \mathrm{log} (h/k_s)+6)^2}$$


## Notations

- \(\alpha\): ratio of the area affected by the bed friction to \(a_x \times a_y\)
- \(\alpha_t\): length scale of turbulence in the block layer (m)
- \(\beta\): ratio between drag stress and turbulence stress
- \(\kappa\): Von Karman constant = 0.41
- \(\sigma\): ratio between the block area in the plane X,y et \(D^2\)
- \(a_x\):  cell width (perpendicular to the flow) (m)
- \(a_y\):  length of a cell (parallel to the flow) (m)
- \(B\): pass width (m)
- \(C\): blocks concentration
- \(C_d\): drag coefficient of a block under current flow conditions
- \(C_{d0}\): drag coefficient of a block considering an infinitely high block with \(F \ll 1\)
- \(C_f)\): bed friction coefficient
- \(d\): displacement in the zero plane of the logarithmic profile (m)
- \(D\): width of the block facing the flow (m)
- \(F\): Froude number based on \(h\) and \(V_g\)
- \(g\): acceleration of gravity = 9.81 m.s<sup>-2</sup>
- \(h\): average depth (m)
- \(h_*\): dimensionless depth (\(h / D\))
- \(k\): useful block height (m)
- \(k_s\): roughness height (m)
- \(l_0\): length scale of turbulence at the top of the blocks (m)
- \(N\): ratio between bed friction and drag force
- \(Q\): flow (m<sup>3</sup>/s)
- \(S\): pass slope (m/m)
- \(u_0\): average bed speed (m/s)
- \(u_*\): shear velocity (m/s)
- \(V\): flow velocity (m/s)
- \(V_g\): velocity between blocks (m/s)
- \(s\): minimum distance between blocks (m)
- \(z\): vertical position (m)
- \(z_0\): hydraulic roughness (m)
- \(\tilde{z}\): dimensionless stand \(\tilde{z} = z / k\)
