import { SelectFieldReference } from "./select-field-reference";
import { SelectEntry } from "./select-entry";
import { ServiceFactory } from "../../services/service-factory";
import { decodeHtml } from "../../util";

import { Session, Solveur } from "jalhyd";

/**
 * A select field that populates itself with references to Nubs
 */
export class SelectFieldNub extends SelectFieldReference {

    protected initSelectedValue() {
        const nub = this.parentForm.currentNub;
        if (nub instanceof Solveur) {
            const ntc = nub.nubToCalculate;
            if (ntc !== undefined) {
                this.setValueFromId(this._entriesBaseId + ntc.uid);
            }
        }
    }

    /**
     * Populates entries with available references
     */
    protected populate() {
        switch (this._source) {
            case "solveur_target": // Solveur, module cible (à calculer)
                // find all Nubs having at least one link to another Nub's result
                const fs = ServiceFactory.instance.formulaireService;
                const candidateNubs =
                    Session.getInstance().getDownstreamNubs().concat(
                        Session.getInstance().getUpstreamNubsHavingExtraResults()
                    ).filter(
                        (element, index, self) => self.findIndex((e) => e.uid === element.uid) === index
                    );
                for (const cn of candidateNubs) {
                    const nub = fs.getFormulaireFromId(cn.uid);
                    if (nub) {
                        const calc = nub.calculatorName;
                        let label = calc;
                        // calculated param
                        if (cn.calculatedParam !== undefined) {
                            const varName = fs.expandVariableName(cn.calcType, cn.calculatedParam.symbol);
                            label += ` / ${varName} (${cn.calculatedParam.symbol})`;
                        }
                        this.addEntry(new SelectEntry(this._entriesBaseId + cn.uid, cn.uid, decodeHtml(label)));
                    } else {
                        // silent fail, this Solveur nub was probably loaded before all the candidate nubs are done loading
                    }
                }
                break;
        }
    }

}
