import { SelectFieldReference } from "./select-field-reference";
import { SelectEntry } from "./select-entry";
import { decodeHtml } from "../../util";
import { ServiceFactory } from "../../services/service-factory";

import { Nub, Solveur } from "jalhyd";

/**
 * A select field that populates itself with references to ParamDefinitions
 */
export class SelectFieldParameter extends SelectFieldReference {

    protected initSelectedValue() {
        const nub = this.parentForm.currentNub;
        if (nub instanceof Solveur) {
            const sp = nub.searchedParameter;
            if (sp !== undefined) {
                this.setValueFromId(this._entriesBaseId + sp.nubUid + "_" + sp.symbol);
            }
        }
    }

    /**
     * Populates entries with available references
     */
    protected populate() {
        switch (this._source) {
            case "solveur_searched": // Solveur, paramètre recherché (à faire varier)
                // find all non-calculated, non-linked parameters of all Nubs that
                // the current "target" Nub depends on (if any)
                const fs = ServiceFactory.instance.formulaireService;
                const solv = this.parentForm.currentNub as Solveur;
                const ntc: Nub = solv.nubToCalculate;
                const searchableParams = Solveur.getDependingNubsSearchableParams(
                    ntc,
                    solv.targettedResult !== undefined && solv.targettedResult !== ""
                );
                for (const p of searchableParams) {
                    if (p.visible) {
                        const calc = fs.getFormulaireFromId(p.originNub.uid).calculatorName;
                        const varName = fs.expandVariableName(p.originNub.calcType, p.symbol);
                        const label = `${p.symbol} - ${varName} (${calc})`;
                        this.addEntry(new SelectEntry(this._entriesBaseId + p.originNub.uid + "_" + p.symbol, p, decodeHtml(label)));
                    }
                }
                break;
        }
    }

}
